@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2023, Victor Ananjevsky <victor@sanana.kiev.ua>
+ * Copyright (C) 2008-2025, Victor Ananjevsky <victor@sanana.kiev.ua>
  */
 
 #include <limits.h>
@@ -30,9 +30,27 @@ static YadSearchBar *search_bar = NULL;
 
 static GString *inbuf;
 
-static gboolean is_loaded = FALSE;
+static volatile gboolean is_loaded = FALSE;
 static gboolean uri_cmd = FALSE;
 
+#define DEFAULT_ZOOM 2
+
+/* get from devhelp */
+static const gdouble zoom_levels[] = {
+  0.5,            /* 50% */
+  0.8408964152,   /* 75% */
+  1.0,            /* 100% */
+  1.1892071149,   /* 125% */
+  1.4142135623,   /* 150% */
+  1.6817928304,   /* 175% */
+  2.0,            /* 200% */
+  2.8284271247,   /* 300% */
+  4.0             /* 400% */
+};
+
+static const guint n_zoom_levels = G_N_ELEMENTS (zoom_levels);
+static guint current_zoom = DEFAULT_ZOOM;
+
 #ifndef PATH_MAX
 #define PATH_MAX 4096
 #endif
@@ -289,6 +307,57 @@ quit_cb (GSimpleAction *act, GVariant *param, gpointer d)
   yad_exit (options.data.def_resp);
 }
 
+static void
+change_zoom (gint lvl)
+{
+  if (lvl == 1)
+    {
+      if (current_zoom < n_zoom_levels)
+        current_zoom++;
+    }
+  else if (lvl == -1)
+    {
+      if (current_zoom > 0)
+        current_zoom--;
+    }
+  else if (lvl == 0)
+    current_zoom = DEFAULT_ZOOM;
+
+  webkit_web_view_set_zoom_level (view, zoom_levels[current_zoom]);
+}
+
+static gboolean
+scroll_cb (GtkWidget *w, GdkEventScroll *ev, gpointer d)
+{
+  gdouble dy;
+
+  if ((ev->state & GDK_CONTROL_MASK) != 0)
+    {
+      switch (ev->direction)
+        {
+        case GDK_SCROLL_UP:
+          change_zoom (1);
+          return GDK_EVENT_STOP;
+
+        case GDK_SCROLL_DOWN:
+          change_zoom (-1);
+          return GDK_EVENT_STOP;
+
+        case GDK_SCROLL_SMOOTH:
+          if (options.html_data.browser)
+            break;
+          gdk_event_get_scroll_deltas ((GdkEvent *) ev, NULL, &dy);
+          change_zoom ((gint) dy);
+          return GDK_EVENT_STOP;
+
+        default:
+          break;
+        }
+    }
+
+  return GDK_EVENT_PROPAGATE;
+}
+
 static gboolean
 menu_cb (WebKitWebView *view, WebKitContextMenu *menu, GdkEvent *ev, WebKitHitTestResult *hit, gpointer d)
 {
@@ -322,24 +391,36 @@ menu_cb (WebKitWebView *view, WebKitContextMenu *menu, GdkEvent *ev, WebKitHitTe
 static gboolean
 key_press_cb (GtkWidget *w, GdkEventKey *key, gpointer d)
 {
-  if ((key->state & GDK_CONTROL_MASK) && (key->keyval == GDK_KEY_O || key->keyval == GDK_KEY_o))
+  if (key->state & GDK_CONTROL_MASK)
     {
-      open_cb (NULL, NULL, d);
-      return TRUE;
-    }
-  else if ((key->state & GDK_CONTROL_MASK) && (key->keyval == GDK_KEY_Q || key->keyval == GDK_KEY_q))
-    {
-      yad_exit (options.data.def_resp);
-      return TRUE;
-    }
-  else if ((key->state & GDK_CONTROL_MASK) && (key->keyval == GDK_KEY_F || key->keyval == GDK_KEY_f))
-    {
-      if (search_bar == NULL)
-        return FALSE;
+      if (key->keyval == GDK_KEY_plus)
+        change_zoom (1);
+      else if (key->keyval == GDK_KEY_minus)
+        change_zoom (-1);
+      else if (key->keyval == GDK_KEY_0)
+        change_zoom (0);
+      else if (options.html_data.browser)
+        {
+          if (key->keyval == GDK_KEY_O || key->keyval == GDK_KEY_o)
+            {
+              open_cb (NULL, NULL, d);
+              return TRUE;
+            }
+          else if (key->keyval == GDK_KEY_Q || key->keyval == GDK_KEY_q)
+            {
+              yad_exit (options.data.def_resp);
+              return TRUE;
+            }
+          else if (key->keyval == GDK_KEY_F || key->keyval == GDK_KEY_f)
+            {
+              if (search_bar == NULL)
+                return FALSE;
 
-      ignore_esc = TRUE;
-      gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (search_bar->bar), TRUE);
-      return gtk_search_bar_handle_event (GTK_SEARCH_BAR (search_bar->bar), (GdkEvent *) key);
+              ignore_esc = TRUE;
+              gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (search_bar->bar), TRUE);
+              return gtk_search_bar_handle_event (GTK_SEARCH_BAR (search_bar->bar), (GdkEvent *) key);
+            }
+        }
     }
 
   return FALSE;
@@ -479,6 +560,9 @@ html_create_widget (GtkWidget * dlg)
   g_signal_connect (view, "decide-policy", G_CALLBACK (policy_cb), NULL);
   g_signal_connect (view, "load-changed", G_CALLBACK (loaded_cb), NULL);
 
+  g_signal_connect (view, "scroll-event", G_CALLBACK (scroll_cb), NULL);
+  g_signal_connect (view, "key-press-event", G_CALLBACK (key_press_cb), dlg);
+
   wk_settings = webkit_settings_new ();
 
   g_object_set (G_OBJECT (wk_settings),
@@ -489,7 +573,6 @@ html_create_widget (GtkWidget * dlg)
   if (options.html_data.browser)
     {
       g_signal_connect (view, "context-menu", G_CALLBACK (menu_cb), dlg);
-      g_signal_connect (view, "key-press-event", G_CALLBACK (key_press_cb), dlg);
       if (!options.data.dialog_title)
         g_signal_connect (view, "notify::title", G_CALLBACK (title_cb), dlg);
       if (!options.data.window_icon)
@@ -568,6 +651,8 @@ html_create_widget (GtkWidget * dlg)
   /* load data */
   if (options.html_data.uri)
     load_uri (options.html_data.uri);
+  else if (options.extra_data)
+    load_uri (options.extra_data[0]);
   else if (!options.html_data.browser)
     {
       GIOChannel *ch;
@@ -578,8 +663,6 @@ html_create_widget (GtkWidget * dlg)
       g_io_channel_set_flags (ch, G_IO_FLAG_NONBLOCK, NULL);
       g_io_add_watch (ch, G_IO_IN | G_IO_HUP, handle_stdin, NULL);
     }
-  else if (options.extra_data)
-    load_uri (options.extra_data[0]);
 
   return w;
 }
