@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2023, Victor Ananjevsky <victor@sanana.kiev.ua>
+ * Copyright (C) 2008-2025, Victor Ananjevsky <victor@sanana.kiev.ua>
  */
 
 #include <string.h>
@@ -756,8 +756,11 @@ get_data_as_string (GtkTreeIter *iter)
     }
 
   str->str[str->len-1] = '\0';
-  res = str->str;
-  g_string_free (str, FALSE);
+#if GLIB_CHECK_VERSION(2,76,0)
+  res = g_string_free_and_steal (str);
+#else
+  res = g_string_free (str, FALSE);
+#endif
 
   return res;
 }
